@@ -59,10 +59,7 @@
 #define GST_DISABLE_TRACE 1
 #define GST_DISABLE_ALLOC_TRACE 1
 #define GST_DISABLE_REGISTRY 1
-#define GST_DISABLE_ENUMTYPES 1
-#define GST_DISABLE_INDEX 1
 #define GST_DISABLE_PLUGIN 1
-#define GST_DISABLE_URI 1
 #define GST_DISABLE_XML 1
 #define GST_DISABLE_LOADSAVE_REGISTRY 1
 #define GST_HAVE_GLIB_2_8 1
@@ -133,18 +130,8 @@
 /* #undef GST_DISABLE_XML */
 
 /* FIXME: test and document these! */
-/* Configure the use of glib enumtypes (useful for introspection)
- * see http://bugzilla.gnome.org/show_bug.cgi?id=342564
- */
-/* #undef GST_DISABLE_ENUMTYPES */
-/* Configure the use of indizies for seeking
- * (not used in plugins right now)
- */
-/* #undef GST_DISABLE_INDEX */
 /* Configures the use of external plugins */
 /* #undef GST_DISABLE_PLUGIN */
-/* Configures the use of uri-handlers */
-/* #undef GST_DISABLE_URI */
 
 /* printf extension format */
 /**
@@ -170,7 +157,7 @@
 #undef GST_USING_PRINTF_EXTENSION
 
 /* whether or not the CPU supports unaligned access */
-#define GST_HAVE_UNALIGNED_ACCESS 0
+#define GST_HAVE_UNALIGNED_ACCESS 1
 
 /* FIXME: 0.11 (remove)
  * whether or not we are using glib 2.8 api, e.g. atomic gobject
