@@ -8,31 +8,35 @@
 
 G_BEGIN_DECLS
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstobject.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstobject.h" */
 GType gst_object_flags_get_type (void);
 #define GST_TYPE_OBJECT_FLAGS (gst_object_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstbin.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstbin.h" */
 GType gst_bin_flags_get_type (void);
 #define GST_TYPE_BIN_FLAGS (gst_bin_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstbuffer.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstbuffer.h" */
 GType gst_buffer_flag_get_type (void);
 #define GST_TYPE_BUFFER_FLAG (gst_buffer_flag_get_type())
 GType gst_buffer_copy_flags_get_type (void);
 #define GST_TYPE_BUFFER_COPY_FLAGS (gst_buffer_copy_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstbus.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstbufferlist.h" */
+GType gst_buffer_list_item_get_type (void);
+#define GST_TYPE_BUFFER_LIST_ITEM (gst_buffer_list_item_get_type())
+
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstbus.h" */
 GType gst_bus_flags_get_type (void);
 #define GST_TYPE_BUS_FLAGS (gst_bus_flags_get_type())
 GType gst_bus_sync_reply_get_type (void);
 #define GST_TYPE_BUS_SYNC_REPLY (gst_bus_sync_reply_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstcaps.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstcaps.h" */
 GType gst_caps_flags_get_type (void);
 #define GST_TYPE_CAPS_FLAGS (gst_caps_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstclock.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstclock.h" */
 GType gst_clock_return_get_type (void);
 #define GST_TYPE_CLOCK_RETURN (gst_clock_return_get_type())
 GType gst_clock_entry_type_get_type (void);
@@ -40,11 +44,11 @@ GType gst_clock_entry_type_get_type (void);
 GType gst_clock_flags_get_type (void);
 #define GST_TYPE_CLOCK_FLAGS (gst_clock_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstdebugutils.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstdebugutils.h" */
 GType gst_debug_graph_details_get_type (void);
 #define GST_TYPE_DEBUG_GRAPH_DETAILS (gst_debug_graph_details_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstelement.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstelement.h" */
 GType gst_state_get_type (void);
 #define GST_TYPE_STATE (gst_state_get_type())
 GType gst_state_change_return_get_type (void);
@@ -54,7 +58,7 @@ GType gst_state_change_get_type (void);
 GType gst_element_flags_get_type (void);
 #define GST_TYPE_ELEMENT_FLAGS (gst_element_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gsterror.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gsterror.h" */
 GType gst_core_error_get_type (void);
 #define GST_TYPE_CORE_ERROR (gst_core_error_get_type())
 GType gst_library_error_get_type (void);
@@ -64,7 +68,7 @@ GType gst_resource_error_get_type (void);
 GType gst_stream_error_get_type (void);
 #define GST_TYPE_STREAM_ERROR (gst_stream_error_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstevent.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstevent.h" */
 GType gst_event_type_flags_get_type (void);
 #define GST_TYPE_EVENT_TYPE_FLAGS (gst_event_type_flags_get_type())
 GType gst_event_type_get_type (void);
@@ -74,11 +78,11 @@ GType gst_seek_type_get_type (void);
 GType gst_seek_flags_get_type (void);
 #define GST_TYPE_SEEK_FLAGS (gst_seek_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstformat.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstformat.h" */
 GType gst_format_get_type (void);
 #define GST_TYPE_FORMAT (gst_format_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstindex.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstindex.h" */
 GType gst_index_certainty_get_type (void);
 #define GST_TYPE_INDEX_CERTAINTY (gst_index_certainty_get_type())
 GType gst_index_entry_type_get_type (void);
@@ -92,27 +96,31 @@ GType gst_index_resolver_method_get_type (void);
 GType gst_index_flags_get_type (void);
 #define GST_TYPE_INDEX_FLAGS (gst_index_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstinfo.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstinfo.h" */
 GType gst_debug_level_get_type (void);
 #define GST_TYPE_DEBUG_LEVEL (gst_debug_level_get_type())
 GType gst_debug_color_flags_get_type (void);
 #define GST_TYPE_DEBUG_COLOR_FLAGS (gst_debug_color_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstiterator.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstiterator.h" */
 GType gst_iterator_result_get_type (void);
 #define GST_TYPE_ITERATOR_RESULT (gst_iterator_result_get_type())
 GType gst_iterator_item_get_type (void);
 #define GST_TYPE_ITERATOR_ITEM (gst_iterator_item_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstmessage.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstmessage.h" */
 GType gst_message_type_get_type (void);
 #define GST_TYPE_MESSAGE_TYPE (gst_message_type_get_type())
+GType gst_structure_change_type_get_type (void);
+#define GST_TYPE_STRUCTURE_CHANGE_TYPE (gst_structure_change_type_get_type())
+GType gst_stream_status_type_get_type (void);
+#define GST_TYPE_STREAM_STATUS_TYPE (gst_stream_status_type_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstminiobject.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstminiobject.h" */
 GType gst_mini_object_flags_get_type (void);
 #define GST_TYPE_MINI_OBJECT_FLAGS (gst_mini_object_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstpad.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstpad.h" */
 GType gst_pad_link_return_get_type (void);
 #define GST_TYPE_PAD_LINK_RETURN (gst_pad_link_return_get_type())
 GType gst_flow_return_get_type (void);
@@ -124,55 +132,69 @@ GType gst_pad_direction_get_type (void);
 GType gst_pad_flags_get_type (void);
 #define GST_TYPE_PAD_FLAGS (gst_pad_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstpadtemplate.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstpadtemplate.h" */
 GType gst_pad_presence_get_type (void);
 #define GST_TYPE_PAD_PRESENCE (gst_pad_presence_get_type())
 GType gst_pad_template_flags_get_type (void);
 #define GST_TYPE_PAD_TEMPLATE_FLAGS (gst_pad_template_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstpipeline.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstpipeline.h" */
 GType gst_pipeline_flags_get_type (void);
 #define GST_TYPE_PIPELINE_FLAGS (gst_pipeline_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstplugin.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstplugin.h" */
 GType gst_plugin_error_get_type (void);
 #define GST_TYPE_PLUGIN_ERROR (gst_plugin_error_get_type())
 GType gst_plugin_flags_get_type (void);
 #define GST_TYPE_PLUGIN_FLAGS (gst_plugin_flags_get_type())
+GType gst_plugin_dependency_flags_get_type (void);
+#define GST_TYPE_PLUGIN_DEPENDENCY_FLAGS (gst_plugin_dependency_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstpluginfeature.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstpluginfeature.h" */
 GType gst_rank_get_type (void);
 #define GST_TYPE_RANK (gst_rank_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstquery.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstquery.h" */
 GType gst_query_type_get_type (void);
 #define GST_TYPE_QUERY_TYPE (gst_query_type_get_type())
+GType gst_buffering_mode_get_type (void);
+#define GST_TYPE_BUFFERING_MODE (gst_buffering_mode_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gsttaglist.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstsystemclock.h" */
+GType gst_clock_type_get_type (void);
+#define GST_TYPE_CLOCK_TYPE (gst_clock_type_get_type())
+
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gsttaglist.h" */
 GType gst_tag_merge_mode_get_type (void);
 #define GST_TYPE_TAG_MERGE_MODE (gst_tag_merge_mode_get_type())
 GType gst_tag_flag_get_type (void);
 #define GST_TYPE_TAG_FLAG (gst_tag_flag_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gsttask.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gsttask.h" */
 GType gst_task_state_get_type (void);
 #define GST_TYPE_TASK_STATE (gst_task_state_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gsttrace.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gsttrace.h" */
 GType gst_alloc_trace_flags_get_type (void);
 #define GST_TYPE_ALLOC_TRACE_FLAGS (gst_alloc_trace_flags_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gsttypefind.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gsttypefind.h" */
 GType gst_type_find_probability_get_type (void);
 #define GST_TYPE_TYPE_FIND_PROBABILITY (gst_type_find_probability_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gsturi.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gsturi.h" */
 GType gst_uri_type_get_type (void);
 #define GST_TYPE_URI_TYPE (gst_uri_type_get_type())
 
-/* enumerations from "/usr/obj/i386/gstreamer-0.10.19p3/gstreamer-0.10.19/gst/gstparse.h" */
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstutils.h" */
+GType gst_search_mode_get_type (void);
+#define GST_TYPE_SEARCH_MODE (gst_search_mode_get_type())
+
+/* enumerations from "/usr/obj/ports/gstreamer-0.10.25/gstreamer-0.10.25/gst/gstparse.h" */
 GType gst_parse_error_get_type (void);
 #define GST_TYPE_PARSE_ERROR (gst_parse_error_get_type())
+GType gst_parse_flags_get_type (void);
+#define GST_TYPE_PARSE_FLAGS (gst_parse_flags_get_type())
 G_END_DECLS
 
 #endif /* __GST_ENUM_TYPES_H__ */
